| Title: | Create Portable R Repositories |
|---|---|
| Description: | Collects together all the bits required to easily install packages from R in situations with limited internet. |
| Authors: | Rich FitzJohn [aut, cre], Thibaut Jombart [aut], Zhian N. Kamvar [ctb] |
| Maintainer: | Rich FitzJohn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-17 05:54:31 UTC |
| Source: | https://github.com/reconhub/nomad |
Build a nomad archive from a github repository
build(ref, dest, progress = NULL) build_path(path, dest, progress = NULL)build(ref, dest, progress = NULL) build_path(path, dest, progress = NULL)
ref |
A reference in |
dest |
Destination directory - must be an empty directory if it exists, otherwise specify a new place. |
progress |
Passed through to |
path |
Path to source, when using |
Create recon usb stick
pack(path, progress = NULL)pack(path, progress = NULL)
path |
Path to download things to. This directory must
already exist, and may contain a |
progress |
Print a progress bar for each downloaded file.
The default |